@@ -3,7 +3,7 @@ package Assert::Refute::Report;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.12';
+our $VERSION = '0.1201';
 
 =head1 NAME
 
@@ -72,7 +72,7 @@ sub new {
 =head3 plan( tests => n )
 
 Plan to run exactly n tests.
-This is not required, and L<done_testing> (see below)
+This is not required, and L</done_testing> (see below)
 is needed at the end anyway.
 
 Dies if there's already a plan, or tests are being run, or done_testing
@@ -80,7 +80,7 @@ was seen.
 
 If plan is not fullfilled by the time of C<done_testing> call,
 a message indicating plan violation will be added,
-and the report will unconditionally failing.
+and the report will become unconditionally failing.
 
 =cut
 
@@ -141,14 +141,14 @@ sub refute {
     diag "Message", \%reference, ...;
 
 Add human-readable diagnostic message to report.
-References are explained to depth 1.
+References are auto-explained via L<Data::Dumper>.
 
 =head3 note
 
     diag "Message", \%reference, ...;
 
 Add human-readable notice message to report.
-References are explained to depth 1.
+References are auto-explained via L<Data::Dumper>.
 
 =cut
 
@@ -238,7 +238,8 @@ C<contract_is>, C<is_deeply>, C<note>, C<diag>.
 See L<Assert::Refute::T::Basic> for more details.
 
 Additionally, I<any> checks defined using L<Assert::Refute::Build>
-will be added to this L<Assert::Refute::Report> by default.
+will be added to L<Assert::Refute::Report> as methods
+unless explicitly told otherwise.
 
 =head3 subcontract( "Message" => $specification, @arguments ... )
 
@@ -381,21 +382,20 @@ Returns a hash containing information about a test:
 
 =over
 
-=item number - the number of test (this is equal to argument);
+=item * number - the number of test (this is equal to argument);
 
-=item ok - whether the test was successful;
+=item * name - name of the test (if any);
 
-=item name - name of the test (if any);
-
-=item reason - the reason for test failing, if it failed;
+=item * ok - whether the test was successful;
 
+=item * reason - the reason for test failing, if it failed;
 Undefined for "ok" tests.
 
-=item diag - diagnostic messages as one array, without leading C<#>;
+=item * diag - diagnostic messages as one array, without leading C<#>;
 
-=item log - any log messages that followed the test (see get_log for format)
+=item * log - any log messages that followed the test (see get_log for format)
 
-=item subcontract - if test was a subcontract, contains the report
+=item * subcontract - if test was a subcontract, contains the report.
 
 =back
 
@@ -405,7 +405,7 @@ As a special case, tests number 0 and -1 represent the output before any
 tests and postmortem output, respectively.
 These only contains the C<log> and C<diag> fields.
 
-See also L<Test::Tester>.
+See also L<Assert::Refute::T::Tester>.
 
 B<[EXPERIMENTAL]>. Name and meaning may change in the future.
 
@@ -476,15 +476,15 @@ B<[NOTE]> that C<diag> is higher than C<ok>.
 
 =over
 
-=item -3 - something totally horrible, like C<Bail out!>
+=item * -3 - something totally horrible, like C<Bail out!>
 
-=item -2 - a failing test
+=item * -2 - a failing test
 
-=item -1 - a diagnostic message, think C<Test::More/diag>
+=item * -1 - a diagnostic message, think C<Test::More/diag>
 
-=item 0 - a passing test
+=item * 0 - a passing test
 
-=item 1+ - a normally ignored verbose message, think L<Test::More/note>
+=item * 1+ - a normally ignored verbose message, think L<Test::More/note>
 
 =back
 
@@ -536,17 +536,17 @@ The format is C<"t(\d+|N)*[rdE]">.
 
 =over
 
-=item C<t> is always present at the start;
+=item * C<t> is always present at the start;
 
-=item a number stands for a series of passing tests;
+=item * a number stands for a series of passing tests;
 
-=item C<N> stands for a I<single> failing test;
+=item * C<N> stands for a I<single> failing test;
 
-=item C<r> stands for a contract that is still B<r>unning;
+=item * C<r> stands for a contract that is still B<r>unning;
 
-=item C<E> stands for a an B<e>xception during execution;
+=item * C<E> stands for a an B<e>xception during execution;
 
-=item C<d> stands for a contract that is B<d>one.
+=item * C<d> stands for a contract that is B<d>one.
 
 =back
 
@@ -745,36 +745,6 @@ copy of the full license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
 
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 =cut
 
 1; # End of Assert::Refute::Report
